@@ -7,7 +7,7 @@ use Moo::Role ();
 
 use Devel::StrictMode;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 sub import {
     my ($class) = @_;
@@ -52,7 +52,7 @@ MooX::Should - optional type restrictions for Moo attributes
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
@@ -83,7 +83,7 @@ attributes at runtime, or to selectively enable them.
 
 Note that you can specify a (weaker) type restriction for an attribute:
 
-  use Types::Common::Numeric qw/ PositiveNum /;
+  use Types::Common::Numeric qw/ PositiveInt /;
   use Types::Standard qw/ Int /;
 
   has thing => (
@@ -133,6 +133,12 @@ feature.
 
 Robert Rothenberg <rrwo@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mohammad S Anwar
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018 by Robert Rothenberg.
